==> sqlc-1.1.0.zip: clib/com/ExecuteCtx.java <==
/*
 * ********************************************************************
 * SQLC Release 1.1.0
 * ********************************************************************
 */
package clib.com;

import java.util.*;

import clib.bean.*;

/**
 * s
 *
 * @since     JDK1.1
 * @author    dynaworks
 */
public  class ExecuteCtx
{
    // ********************************
    // 
    // ********************************
    /** o͖ */
    protected String  comm_name;
    /** caڑ */
    protected String  conn_name;

    protected RecOutBean    reco;

    /** ۑpbZbV */
    protected Hashtable comm_stack = new Hashtable();

    /*******************************************************************
     * \z
     ******************************************************************/
    public ExecuteCtx()
    {
        conn_name = null;
        comm_name = null;
    }

    /*******************************************************************
     * \z(ʍ\z)
     * @param bean s
     ******************************************************************/
    public ExecuteCtx(ExecuteCtx bean)
    {
        this.conn_name = bean.getConnName();
        this.comm_name = bean.getCommName();
        this.reco      = bean.reco();
    }

    /*******************************************************************
     * \z
     * @param comm_name o͖
     * @param conn_name caڑ
     ******************************************************************/
    public ExecuteCtx(String comm_name,String conn_name)
    {
        setConnName(conn_name);
        setCommName(comm_name);
    }


    /*******************************************************************
     * o͖̎擾
     * @return  o͖
     ******************************************************************/
    public String getCommName()
    {
        return comm_name;
    }
    /*******************************************************************
     * o͖̐ݒ
     * @param   comm_name o͖
     ******************************************************************/
    public void setCommName(String comm_name)
    {
        this.comm_name = comm_name;
    }

    /*******************************************************************
     * caڑ̎擾
     * @return  caڑ
     ******************************************************************/
    public String getConnName()
    {
        return conn_name;
    }
    /*******************************************************************
     * caڑ̐ݒ
     * @param   conn_name caڑ
     ******************************************************************/
    public void setConnName(String conn_name)
    {
        this.conn_name = conn_name;
    }

    /*******************************************************************
     * bZbV̑ޔ
     * @param   id ʎq
     ******************************************************************/
    public void pushComm(Object id)
    {
        comm_stack.put(id.toString(),comm_name);
    }
    /*******************************************************************
     * bZbV̕
     * @param   id ʎq
     ******************************************************************/
    public void popComm(Object id)
    {
        String name = (String)comm_stack.remove(id.toString());
        if( name != null ) setCommName(name);
    }


    /*******************************************************************
     * bZbV̎擾
     * @return  bZbV
     ******************************************************************/
    public CommBean comm()
    {
        return CommBeanMan.getInstance().getCtx(comm_name);
    }
    /*******************************************************************
     * DBڑZbV̎擾
     * @return  DBڑZbV
     ******************************************************************/
    public ConnBean conn()
    {
        return ConnBeanMan.getInstance().getCtx(conn_name);
    }
    /*******************************************************************
     * DBڑZbV̎擾
     * @return  DBڑZbV
     ******************************************************************/
    public RecOutBean reco()
    {
        return reco;
    }

}

==> sqlc-1.2.0.zip: clib/com/ExecuteCtx.java <==
package clib.com;

import java.io.*;
import java.util.*;

import clib.bean.*;

/**
 * s
 *
 * @since     JDK1.1
 * @author    dynaworks
 */
public  class ExecuteCtx
{
    private static ExecuteCtx ctx = new ExecuteCtx();

    // ********************************
    // 
    // ********************************
    /** o͖ */
    protected String comm_name;
    /** caڑ */
    protected String conn_name;

    protected RecOutBean  reco;

    /** ۑpbZbV */
    protected Hashtable comm_stack = new Hashtable();

    /** ۑpbZbV */
    protected Hashtable conn_stack = new Hashtable();

    /*******************************************************************
     * \z
     ******************************************************************/
    private ExecuteCtx()
    {
        conn_name = null;
        comm_name = null;
    }

    /*******************************************************************
     * 擾
     * @return   bZbVǗ
     ******************************************************************/
    static public ExecuteCtx getInstance()
    {
        return ctx;
    }

    /*******************************************************************
     * o͖̐ݒ
     * @param   comm_name o͖
     ******************************************************************/
    public void setCommConnName(String comm_name,String conn_name)
    {
        setCommName(comm_name);
        setConnName(comm_name);
    }

    /*******************************************************************
     * o͖̎擾
     * @return  o͖
     ******************************************************************/
    public String getCommName()
    {
        return comm_name;
    }
    /*******************************************************************
     * o͖̐ݒ
     * @param   comm_name o͖
     ******************************************************************/
    public void setCommName(String comm_name)
    {
        this.comm_name = comm_name;
    }

    /*******************************************************************
     * caڑ̎擾
     * @return  caڑ
     ******************************************************************/
    public String getConnName()
    {
        return conn_name;
    }
    /*******************************************************************
     * caڑ̐ݒ
     * @param   conn_name caڑ
     ******************************************************************/
    public void setConnName(String conn_name)
    {
        this.conn_name = conn_name;
    }


    /*******************************************************************
     * bZbV̑ޔ
     * @param   id ʎq
     ******************************************************************/
    public void pushComm(Object id)
    {
        if( comm_name != null )
            comm_stack.put(id.toString(),comm_name);
    }
    /*******************************************************************
     * bZbV̕
     * @param   id ʎq
     ******************************************************************/
    public boolean popComm(Object id)
    {
        String name = (String)comm_stack.remove(id.toString());
        if( name == null ) return false;
        setCommName(name);
        return true;
    }
    /*******************************************************************
     * bZbV̎擾
     * @return  bZbV
     ******************************************************************/
    public CommBean comm()
    {
        return CommBeanMan.getInstance().getCtx(comm_name);
    }

    public void createComm(Object obj,String name,InputStream is,OutputStream os)
    {
//System.out.println("'"+getCommName()+"'->'"+name+"'");
        pushComm(obj);
        CommBean comm = new CommBean(name,is,os);
        setCommName(name);
        comm.startup();
        CommBeanMan.getInstance().addCtx(comm);
    }

    public void deleteComm(Object obj)
    {
        String name = getCommName();

        if( popComm(obj) )
            CommBeanMan.getInstance().removeCtx(name);
//System.out.println("'"+getCommName()+"'<-'"+name+"'");
    }

    /*******************************************************************
     * DBڑZbV̑ޔ
     * @param   id ʎq
     ******************************************************************/
    public void pushConn(Object id)
    {
        if( conn_name != null )
            conn_stack.put(id.toString(),conn_name);
    }
    /*******************************************************************
     * DBڑZbV̕
     * @param   id ʎq
     ******************************************************************/
    public boolean popConn(Object id)
    {
        String name = (String)conn_stack.remove(id.toString());
        if( name == null ) return false;
        setConnName(name);
        return true;
    }
    /*******************************************************************
     * DBڑZbV̎擾
     * @return  DBڑZbV
     ******************************************************************/
    public ConnBean conn()
    {
        return ConnBeanMan.getInstance().getCtx(conn_name);
    }

    /*******************************************************************
     * DBڑZbV̎擾
     * @return  DBڑZbV
     ******************************************************************/
    public RecOutBean reco()
    {
        return reco;
    }

}
